@@ -1,16 +1,16 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-"""
-@File    :   fedhf\component\logger\logger.py
-@Time    :   2021-10-26 11:06:47
-@Author  :   Bingjie Yan
-@Email   :   bj.yan.pa@qq.com
-@License :   Apache License 2.0
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\api\logger\logger.py
+# @Time    :   2022-05-03 15:58:38
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
+import os
 import logging
 import sys
 import wandb
+import time
 
 from .base_logger import BaseLogger, logger_map
 
@@ -20,7 +20,9 @@ logging.basicConfig(stream=sys.stdout,
 
 
 class Logger(BaseLogger):
+
     class __Logger(BaseLogger):
+
         def __init__(self, args):
             if args.log_level in logger_map:
                 self.log_level = logger_map[args.log_level]
@@ -35,14 +37,16 @@ class Logger(BaseLogger):
             self.logger = logging.getLogger(self.log_name)
             self.logger.setLevel(self.log_level)
 
-            formatter = logging.Formatter(
-                '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+            formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
 
-            if args.log_file is not None:
-                file_handler = logging.FileHandler(args.log_file, mode='w')
-                file_handler.setLevel(level=self.log_level)
-                file_handler.setFormatter(formatter)
-                self.logger.addHandler(file_handler)
+            if args.log_file is None:
+                os.makedirs(os.path.join('log'), exist_ok=True)
+                args.log_file = os.path.join('log', f'log_{int(time.time())}.log')
+
+            file_handler = logging.FileHandler(args.log_file, mode='w')
+            file_handler.setLevel(level=self.log_level)
+            file_handler.setFormatter(formatter)
+            self.logger.addHandler(file_handler)
 
             # use streamHandler to print to stdout
             stream_handler = logging.StreamHandler(sys.stdout)
