@@ -1,12 +1,10 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-"""
-@File    :   fedhf\component\serial\serializer.py
-@Time    :   2021-11-10 16:54:44
-@Author  :   Bingjie Yan
-@Email   :   bj.yan.pa@qq.com
-@License :   Apache License 2.0
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\api\serial\serializer.py
+# @Time    :   2022-05-03 15:59:29
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
 import torch
 
@@ -15,6 +13,7 @@ class Serializer(object):
     """
     Serializer
     """
+
     @staticmethod
     def serialize_model_grad(model: torch.nn.Module) -> torch.Tensor:
         grads = [param.data.grad.view(-1) for param in model.parameters()]
