@@ -1,18 +1,17 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-"""
-@File    :   fedhf\component\aggregator\base_aggregator.py
-@Time    :   2021-10-26 20:33:11
-@Author  :   Bingjie Yan
-@Email   :   bj.yan.pa@qq.com
-@License :   Apache License 2.0
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\component\aggregator\base_aggregator.py
+# @Time    :   2022-05-03 15:59:51
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
 from abc import ABC, abstractmethod
 from fedhf.api import Logger
 
 
 class AbsAggregator(ABC):
+
     def __init__(self) -> None:
         super().__init__()
 
@@ -26,6 +25,7 @@ class AbsAggregator(ABC):
 
 
 class BaseAggregator(AbsAggregator):
+
     def __init__(self, args) -> None:
         self.args = args
         self.logger = Logger(self.args)
