@@ -1,12 +1,10 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-"""
-@File    :   fedhf\component\sampler\__init__.py
-@Time    :   2021-10-26 16:46:48
-@Author  :   Bingjie Yan
-@Email   :   bj.yan.pa@qq.com
-@License :   Apache License 2.0
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\component\sampler\__init__.py
+# @Time    :   2022-05-03 16:00:35
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
 __all__ = ["build_sampler", "RandomSampler", "NonIIDSampler", "sampler_factory", "BaseSampler"]
 
