@@ -1,12 +1,10 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-"""
-@File    :   fedhf\component\selector\__init__.py
-@Time    :   2021-11-08 21:14:03
-@Author  :   Bingjie Yan
-@Email   :   bj.yan.pa@qq.com
-@License :   Apache License 2.0
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\component\selector\__init__.py
+# @Time    :   2022-05-03 16:00:53
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
 __all__ = ["build_selector", "RandomFedAsyncSelector", "RandomSelector", "selector_factory"]
 
