@@ -1,12 +1,10 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-""" 
-@File    :   fedhf\component\selector\random_async_selector.py 
-@Time    :   2021-11-15 23:02:09 
-@Author  :   Bingjie Yan 
-@Email   :   bj.yan.pa@qq.com 
-@License :   Apache License 2.0 
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\component\selector\random_fedasync_selector.py
+# @Time    :   2022-05-03 16:01:01
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
 import numpy as np
 
@@ -14,6 +12,7 @@ from .base_selector import BaseSelector
 
 
 class RandomFedAsyncSelector(BaseSelector):
+
     def __init__(self, args) -> None:
         self.args = args
 
@@ -22,6 +21,7 @@ class RandomFedAsyncSelector(BaseSelector):
         select_ratio = self.args.select_ratio
         select_count = min(int(self.args.num_clients * select_ratio),
                            self.args.fedasync_max_staleness)
+        select_count = max(1, select_count)
         selected_clients = np.random.choice(client_list, select_count, replace=False)
         # np.random.shuffle(selected_clients)
         return selected_clients
