@@ -1,12 +1,10 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-"""
-@File    :   fedhf\component\trainer\__init__.py
-@Time    :   2021-10-26 20:43:41
-@Author  :   Bingjie Yan
-@Email   :   bj.yan.pa@qq.com
-@License :   Apache License 2.0
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\component\trainer\__init__.py
+# @Time    :   2022-05-03 16:01:12
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
 __all__ = ["Trainer", "FedAsyncTrainer", "build_trainer", "trainer_factory", "BaseTrainer"]
 
