@@ -1,17 +1,15 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-"""
-@File    :   fedhf\component\client\base_client.py
-@Time    :   2021-10-26 11:06:33
-@Author  :   Bingjie Yan
-@Email   :   bj.yan.pa@qq.com
-@License :   Apache License 2.0
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\core\client\base_client.py
+# @Time    :   2022-05-03 15:55:52
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
 from abc import ABC, abstractmethod
 
 from fedhf.api import Logger
-from fedhf.component import build_evaluator, build_trainer
+from fedhf.component import build_evaluator, build_trainer, build_encryptor
 from fedhf.model import build_criterion, build_model, build_optimizer
 
 
@@ -34,5 +32,6 @@ class BaseClient(AbsClient):
 
         self.trainer = build_trainer(self.args.trainer)(self.args)
         self.evaluator = build_evaluator(self.args.evaluator)(self.args)
+        # self.encryptor = build_encryptor(self.args.encryptor)(self.args)
 
         self.logger = Logger(args)
