@@ -1,12 +1,10 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-"""
-@File    :   fedhf\component\server\simulated_server.py
-@Time    :   2021-10-26 21:44:30
-@Author  :   Bingjie Yan
-@Email   :   bj.yan.pa@qq.com
-@License :   Apache License 2.0
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\core\server\simulated_server.py
+# @Time    :   2022-05-03 03:34:11
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
 from copy import deepcopy
 import re
@@ -21,10 +19,16 @@ from .base_server import BaseServer
 
 
 class SimulatedServer(BaseServer):
+
     def __init__(self, args) -> None:
         super(SimulatedServer, self).__init__(args)
 
     def update(self, model: nn.Module, **kwargs):
+        # self.logger.info(f'Update model with {kwargs}')
+
+        if self.model.get_model_version() == 0:
+            self.model = deepcopy(model)
+
         result = self.aggregator.agg(Serializer.serialize_model(self.model),
                                      Serializer.serialize_model(model), **kwargs)
 
@@ -33,6 +37,9 @@ class SimulatedServer(BaseServer):
             return
         # print(self.model.get_model_version(), model.get_model_version())
         Deserializer.deserialize_model(self.model, result['param'])
+
+        # self.model = self.encryptor.encrypt_model(self.model)
+
         self.model.set_model_version(result['model_version'])
         self.model.set_model_time(result['model_time'])
         # print(result['model_version'], result['model_time'])
