@@ -1,12 +1,10 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-""" 
-@File    :   fedhf\model\network\__init__.py 
-@Time    :   2022-01-24 11:49:23 
-@Author  :   Bingjie Yan 
-@Email   :   bj.yan.pa@qq.com 
-@License :   Apache License 2.0 
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\model\nn\__init__.py
+# @Time    :   2022-05-03 16:06:57
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
 from .resnet import ResNet
 from .resnet_mnist import ResNetMNIST
@@ -15,7 +13,7 @@ from .alexnet_cifar10 import AlexNetCIFAR10
 from .cnn_cifar10 import CNN2CIFAR10, CNN4CIFAR10
 from .cnn_mnist import CNNMNIST
 from .densenet import DenseNet
-from .unet import UNet
+from .unet import UNet, UNetMini
 from .base_model import BaseModel
 
 model_factory = {
@@ -30,6 +28,7 @@ model_factory = {
     'cnn_mnist': CNNMNIST,
     'densenet': DenseNet,
     'unet': UNet,
+    'unet_mini': UNetMini,
 }
 
 
