@@ -1,12 +1,10 @@
 #!/usr/bin/env python
-# -*- encoding: utf-8 -*-
-""" 
-@File    :   fedhf\model\cnn_cifar10.py 
-@Time    :   2021-11-19 16:54:56 
-@Author  :   Bingjie Yan 
-@Email   :   bj.yan.pa@qq.com 
-@License :   Apache License 2.0 
-"""
+# -*- coding: utf-8 -*-
+# @File    :   fedhf\model\nn\cnn_mnist.py
+# @Time    :   2022-05-03 16:07:17
+# @Author  :   Bingjie Yan
+# @Email   :   bj.yan.pa@qq.com
+# @License :   Apache License 2.0
 
 import torch
 import torch.nn as nn
@@ -19,8 +17,9 @@ class CNNMNIST(BaseModel):
     """
     Implentation of the cnn described in the fedasync
     """
-    def __init__(self, args, model_time=0):
-        super().__init__(args, model_time)
+
+    def __init__(self, args, model_time=None, model_version=0):
+        super().__init__(args, model_time, model_version)
 
         self.num_classes = args.num_classes
 
